==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/comments.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_PageReply($story,$where,$topinfo,$score,$reply=0) {
	global	$comment_sort,$cmode,$p,$trackback,$LAYOUT;
	$CONF = KWL_GetConf();

   if ($CONF['tbmsg_show'] && $trackback) { include_once("tb_msgs.php"); }
   
	$page_start = ($CONF['PAGE_REPLY_LIMIT'] * $p) - $CONF['PAGE_REPLY_LIMIT'];
	$blah = KWL_npLink(SqlCount("T_Comments","ParentRid",$story),$p,"$where&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$score",$CONF['PAGE_REPLY_LIMIT'],10,"p");
	
	if ($blah) {
		$blah = _REPLY_PAGE_DESC . " $blah ("
		      . _REPLY_PAGES_DESC . ": " . $CONF['PAGE_REPLY_LIMIT'] . ")";
	}

	if ($cmode=="unthread") {
		KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
		KWL_doUnthread($story,$comment_sort,$cmode,$page_start,$CONF['PAGE_REPLY_LIMIT'],$where,1);
		KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
		return;
	}

	$sql	 = "SELECT * FROM T_Comments ";
	$sql	.= "WHERE ParentRid = '$story' AND TopRid = '$story' ";
	if (empty($comment_sort)) $comment_sort = strtolower($CONF["CommentSort"]);
	$sql	.= "ORDER By Birthstamp $comment_sort ";
	$sql	.= "LIMIT $page_start,$CONF[PAGE_REPLY_LIMIT]";

	$result	= SqlQuery($sql);
	if (!mysql_num_rows($result)) return;

	KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
	while ($A = mysql_fetch_array($result)) {
		if ($A["score"] >= $score ) {
			$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
			if ($CONF['admin_login']) $A["Content"] .= KWL_AdminLinki("T_Comments",$A['Rid'],urlencode($where));
			KWL_DrawComment($A,"$where" . "&amp;p=$p&amp;cmode=$cmode&amp;comment_sort=$comment_sort");
		} else {
			echo "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\"><tr><td><img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" />&nbsp;<a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$story&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<img src=\"$CONF[G_URL]/images.d/speck.gif\" height=\"1\" width=\"270\"></td></tr></table>\n";
		}
		switch ($cmode) {
			case "thread":
				echo "<ul>\n";
				KWL_doComments($A["Rid"],$story,$where,$reply+1,1);
				echo "</ul>\n";
			break;
			case "flat":
				KWL_doComments($A["Rid"],$story,$where,0);
			break;
			default: KWL_doComments($A["Rid"],$story,$where,$reply+1);
		}
	}
	KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
}

function KWL_doComments($rid,$toprid,$where,$reply=0,$thread=0) {
	global	$comment_sort,$cmode,$score;
	$CONF = KWL_GetConf();
	
	if (empty($comment_sort)) $comment_sort = strtolower($CONF["CommentSort"]);
	if ($cmode=="unthread") {
		KWL_doUnthread($toprid,$comment_sort,$cmode,'','',$where);
		return;
	}

	$result	= SqlQuery("SELECT * FROM T_Comments WHERE ParentRid = '$rid' ORDER By Birthstamp $comment_sort");
	
	if (!mysql_num_rows($result)) return;
	
	while ($A = mysql_fetch_array($result)) {
		if ($thread) {
			if ($A["score"] >= $score )
				echo "<li><a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$toprid&amp;cmode=$cmode&amp;comment_sort=$comment_sort#$A[Rid]\">Re: ". $A['Author'] ." (". KWL_DateFormat($A["Birthstamp"]) .")</a></li>\n";
			else
				echo "<li><a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$toprid&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<br />\n";
		} else {
			if ($reply) echo "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\"><tr><td width=\"". $reply * 25 ."\"><img src=\"$CONF[G_URL]/images.d/speck.gif\" height=\"1\" width=\"". $reply * 25 ."\" /></td><td>";
			if ($A["score"] >= $score) { 
				$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
				if ($CONF['admin_login']) $A["Content"] .= KWL_AdminLinki("T_Comments",$A["Rid"],urlencode($where));
				KWL_DrawComment($A,$where);
			} else {
				echo "<table border=0 cellpadding=0 cellspacing=0 width=100%><tr><td><img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" />&nbsp;<a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$toprid&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<img src=\"$CONF[G_URL]/images.d/speck.gif\" height=\"1\" width=\"270\"></td></tr></table>\n";
			}
			if ($reply) echo "</td></tr></table>\n";
		}
		switch ($cmode) {
			case "thread":
				echo "<ul>\n";
				KWL_doComments($A["Rid"],$toprid,$where,$reply+1,1);
				echo "</ul>\n";
			break;
			case "flat":
				KWL_doComments($A["Rid"],$toprid,$where,0);
			break;
			default: KWL_doComments($A["Rid"],$toprid,$where,$reply+1);
		}
	}
}

function KWL_doUnthread($rid,$sort,$nest,$start='',$end='',$where,$fix=0) {
	global	$score;
	$CONF = KWL_GetConf();
	
	/* ignore thread, just loop */
	$sql = "SELECT * FROM T_Comments WHERE TopRid = '$rid' ORDER By Birthstamp $sort";
	if ($fix) $sql .= " LIMIT $start,$end";
	$result = SqlQuery($sql);
	if (mysql_num_rows($result)) {
		while ($A = mysql_fetch_array($result)) {
			$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
			if ($CONF['admin_login']) $A['Content'] .= KWL_AdminLinki("T_Comments",$A['Rid'],urlencode($where));
			if ($A["score"] >= $score ) KWL_DrawComment($A,$where);
			else echo "<table border=0 cellpadding=0 cellspacing=0 width=100%><tr><td><img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" />&nbsp;<a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$rid&amp;cmode=$nest&amp;comment_sort=$sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<img src=\"$CONF[G_URL]/images.d/speck.gif\" height=1 width=\"270\" /></td></tr></table>\n";
		}
	mysql_free_result($result);
	}
	return;
}

function KWL_PostComment($parentrid,$toprid,$where,$oscore="",$fix=0,$otxt='') {
   global   $size,$agent,$login,$user,$C_USER;
   $CONF = KWL_GetConf();
   
   if ($CONF['Comments']) {
      include_once("$CONF[G_PATH]/include/cform.inc.php");
   } else return;
}

function KWL_SortComment($form_act,$fix=1,$topinfo='',$page_link='') {
   global $site_theme,$score,$cmode,$comment_sort;

   $CONF = KWL_GetConf();
   $out = new KWL_Html;

   if (empty($comment_sort)) $comment_sort = strtolower($CONF['CommentSort']);
   $sort = "";
   if (!empty($CONF['SCORING'])) {
         $sort = _SCORE . " : "
            . $out->select("sc", array( -1 => "-1 : $topinfo[renum]",
                                         0 => "0 : $topinfo[renum0]",
                                         1 => "1 : $topinfo[renum1]"),
                           $score) . "&nbsp;";
   }
   $sort .= _BLOCK_SORT . " : "
      . $out->select("cmode", array( "nest"     => "Nested",
                                     "thread"   => "Threaded",
                                     "flat"     => "Flat",
                                     "unthread" => "Unthreaded"),
                     $cmode) . "&nbsp;"
      . $out->select("comment_sort",array( "desc" => _SORT_NEW,
                                           "asc"  => _SORT_OLD), $comment_sort)
      . $out->input_form("HIDDEN","hide",1)
      . $out->input_form("SUBMIT","mode","ok");
   if ($fix) {
         $heading = "<a class=\"title\" href=\"stories.php?story=$topinfo[Rid]&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$score\">"
            . $topinfo['title'] . "</a>"
            . " | " . _COMMENTS . ": " . $topinfo['renum'];
         if ($CONF['Language'] == "korean") $heading .= _FIX;
         $heading .= " | <a class=\"title\" href=\"$CONF[G_URL]/write.php?sid=$topinfo[Rid]\">". _PARENT ."</a>";
         if ($topinfo['renum']>9) $heading .= " | <a class=\"title\" href=\"search.php?story=$topinfo[Rid]\">". _CSEARCH ."</a>";
   } else $heading = "";
   $templatefile  = "$CONF[G_PATH]/backend/template/$site_theme/sort_block.tmpl";
   $imagedir   = "$CONF[G_URL]/backend/template/$site_theme/images";
   $templ_arr  = @file($templatefile);
   $template   = @implode("", $templ_arr);
   $template   = addslashes($template);
   $tmp        = "print \"" . $template . "\";";

   echo $out->form_start($form_act,"sort");
   print eval($tmp);
   echo $out->form_end();
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/include/comments.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_PageReply($story,$where,$topinfo,$score,$reply=0) {
	global	$comment_sort,$cmode,$p,$trackback,$LAYOUT;
	$CONF = KWL_GetConf();

   if ($CONF['tbmsg_show'] && $trackback) { 
      include("{$CONF['G_PATH']}/include/tb_msgs.php");
   }   
   
	$page_start = ($CONF['PAGE_REPLY_LIMIT'] * $p) - $CONF['PAGE_REPLY_LIMIT'];
	$blah = KWL_npLink(SqlCount("T_Comments","ParentRid",$story),$p,"$where&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$score",$CONF['PAGE_REPLY_LIMIT'],10,"p");
	
	if ($blah) {
		$blah = _REPLY_PAGE_DESC . " $blah ("
		      . _REPLY_PAGES_DESC . ": " . $CONF['PAGE_REPLY_LIMIT'] . ")";
	}

	if ($cmode=="unthread") {
		KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
		KWL_doUnthread($story,$comment_sort,$cmode,$page_start,$CONF['PAGE_REPLY_LIMIT'],$where,1);
		KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
		return;
	}

	$sql	 = "SELECT * FROM T_Comments ";
	$sql	.= "WHERE ParentRid = '$story' AND TopRid = '$story' ";
	if (empty($comment_sort)) $comment_sort = strtolower($CONF["CommentSort"]);
	$sql	.= "ORDER By Birthstamp $comment_sort ";
	$sql	.= "LIMIT $page_start,$CONF[PAGE_REPLY_LIMIT]";

	$result	= SqlQuery($sql);
	if (!mysql_num_rows($result)) return;

	KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
	while ($A = mysql_fetch_array($result)) {
		if ($A["score"] >= $score ) {
			$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
			if ($CONF['admin_login']) $A["Content"] .= KWL_AdminLinki("T_Comments",$A['Rid'],urlencode($where));
			KWL_DrawComment($A,"$where" . "&amp;p=$p&amp;cmode=$cmode&amp;comment_sort=$comment_sort");
		} else {
			echo "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\"><tr><td><img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" /><a name=\"$A[Rid]\">&nbsp;</a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$story&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<img src=\"$CONF[G_URL]/images.d/speck.gif\" height=\"1\" width=\"270\"></td></tr></table>\n";
		}
		switch ($cmode) {
			case "thread":
				echo "<ul>\n";
				KWL_doComments($A["Rid"],$story,$where,$reply+1,1);
				echo "</ul>\n";
			break;
			case "flat":
				KWL_doComments($A["Rid"],$story,$where,0);
			break;
			default: KWL_doComments($A["Rid"],$story,$where,$reply+1);
		}
	}
	KWL_SortComment("$where&amp;p=$p",1,$topinfo,$blah);
}

function KWL_doComments($rid,$toprid,$where,$reply=0,$thread=0) {
	global	$comment_sort,$cmode,$score;
	$CONF = KWL_GetConf();
	
	if (empty($comment_sort)) $comment_sort = strtolower($CONF["CommentSort"]);
	if ($cmode=="unthread") {
		KWL_doUnthread($toprid,$comment_sort,$cmode,'','',$where);
		return;
	}

	$result	= SqlQuery("SELECT * FROM T_Comments WHERE ParentRid = '$rid' ORDER By Birthstamp $comment_sort");
	
	if (!mysql_num_rows($result)) return;
	
	while ($A = mysql_fetch_array($result)) {
		if ($thread) {
			if ($A["score"] >= $score )
				echo "<li><a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$toprid&amp;cmode=$cmode&amp;comment_sort=$comment_sort#$A[Rid]\">Re: ". $A['Author'] ." (". KWL_DateFormat($A["Birthstamp"]) .")</a></li>\n";
			else
				echo "<li><a name=\"$A[Rid]\"></a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$toprid&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])</li>\n";
		} else {
			if ($reply) echo "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" width=\"100%\"><tr><td width=\"". $reply * 25 ."\"><img src=\"$CONF[G_URL]/images.d/speck.gif\" height=\"1\" width=\"". $reply * 25 ."\" /></td><td>";
			if ($A["score"] >= $score) { 
				$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
				if ($CONF['admin_login']) $A["Content"] .= KWL_AdminLinki("T_Comments",$A["Rid"],urlencode($where));
				KWL_DrawComment($A,$where);
			} else {
				echo "<table border='0' cellpadding='0' cellspacing='0' width='100%'><tr><td><img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" /><a name=\"$A[Rid]\">&nbsp;</a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$toprid&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<img src=\"$CONF[G_URL]/images.d/speck.gif\" height=\"1\" width=\"270\"></td></tr></table>\n";
			}
			if ($reply) echo "</td></tr></table>\n";
		}
		switch ($cmode) {
			case "thread":
				echo "<ul>\n";
				KWL_doComments($A["Rid"],$toprid,$where,$reply+1,1);
				echo "</ul>\n";
			break;
			case "flat":
				KWL_doComments($A["Rid"],$toprid,$where,0);
			break;
			default: KWL_doComments($A["Rid"],$toprid,$where,$reply+1);
		}
	}
}

function KWL_doUnthread($rid,$sort,$nest,$start='',$end='',$where,$fix=0) {
	global	$score;
	$CONF = KWL_GetConf();
	
	/* ignore thread, just loop */
	$sql = "SELECT * FROM T_Comments WHERE TopRid = '$rid' ORDER By Birthstamp $sort";
	if ($fix) $sql .= " LIMIT $start,$end";
	$result = SqlQuery($sql);
	if (mysql_num_rows($result)) {
		while ($A = mysql_fetch_array($result)) {
			$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
			if ($CONF['admin_login']) $A['Content'] .= KWL_AdminLinki("T_Comments",$A['Rid'],urlencode($where));
			if ($A["score"] >= $score ) KWL_DrawComment($A,$where);
			else echo "<table border='0' cellpadding='0' cellspacing='0' width='100%'><tr><td><img src=\"$CONF[G_URL]/images.d/comment.gif\" height=\"11\" width=\"14\" /><a name=\"$A[Rid]\">&nbsp;</a><a href=\"comments.php?rid=$A[ParentRid]&amp;story=$rid&amp;cmode=$nest&amp;comment_sort=$sort&amp;sc=$A[score]#$A[Rid]\">" . _HIDDEN . "</a> (". _SCORE .": $A[score])<img src=\"$CONF[G_URL]/images.d/speck.gif\" height='1' width=\"270\" /></td></tr></table>\n";
		}
	mysql_free_result($result);
	}
	return;
}

function KWL_PostComment($parentrid,$toprid,$where,$oscore="",$fix=0,$otxt='') {
   global   $size,$agent,$login,$user,$C_USER;
   $CONF = KWL_GetConf();
   
   if ($CONF['Comments']) {
      include_once("$CONF[G_PATH]/include/cform.inc.php");
   } else return;
}

function KWL_SortComment($form_act,$fix=1,$topinfo='',$page_link='') {
   global $site_theme,$score,$cmode,$comment_sort;

   $CONF = KWL_GetConf();
   $out = new KWL_Html;

   if (empty($comment_sort)) $comment_sort = strtolower($CONF['CommentSort']);
   $sort = "";
   if (!empty($CONF['SCORING'])) {
         $sort = _SCORE . " : "
            . $out->select("sc", array( -1 => "-1 : $topinfo[renum]",
                                         0 => "0 : $topinfo[renum0]",
                                         1 => "1 : $topinfo[renum1]"),
                           $score) . "&nbsp;";
   }
   $sort .= _BLOCK_SORT . " : "
      . $out->select("cmode", array( "nest"     => "Nested",
                                     "thread"   => "Threaded",
                                     "flat"     => "Flat",
                                     "unthread" => "Unthreaded"),
                     $cmode) . "&nbsp;"
      . $out->select("comment_sort",array( "desc" => _SORT_NEW,
                                           "asc"  => _SORT_OLD), $comment_sort)
      . $out->input_form("hidden","hide",1)
      . $out->input_form("submit","mode","ok");
   if ($fix) {
         $heading = "<a class=\"title\" href=\"stories.php?story=$topinfo[Rid]&amp;cmode=$cmode&amp;comment_sort=$comment_sort&amp;sc=$score\">"
            . $topinfo['title'] . "</a>"
            . " | " . _COMMENTS . ": " . $topinfo['renum'];
         if ($CONF['Language'] == "korean") $heading .= _FIX;

         if ($CONF['Backend']) {
            $heading .= "(<a title=\"RSS 2.0\" href=\"{$CONF['G_URL']}/rss.php?s={$topinfo['Rid']}\">RSS</a>) ";
         }
         
         $heading .= " | <a class=\"title\" href=\"$CONF[G_URL]/write.php?sid=$topinfo[Rid]\">". _PARENT ."</a>";
         if ($topinfo['renum']>9) $heading .= " | <a class=\"title\" href=\"search.php?story=$topinfo[Rid]\">". _CSEARCH ."</a>";
   } else $heading = "";
   $templatefile  = "$CONF[G_PATH]/backend/template/$site_theme/sort_block.tmpl";
   $imagedir   = "$CONF[G_URL]/backend/template/$site_theme/images";
   $templ_arr  = @file($templatefile);
   $template   = @implode("", $templ_arr);
   $template   = addslashes($template);
   $tmp        = "print \"" . $template . "\";";

   echo $out->form_start($form_act,"sort");
   print eval($tmp);
   echo $out->form_end();
}
?>
